@@ -1,4 +1,5 @@
 #include <vector>
+#include <string>
 
 
 class CLimiter {
@@ -9,6 +10,9 @@ class CLimiter {
         std::vector<float> limit(const std::vector<float> &audio);
         void reset();
 
+        void read_from_string(const std::string &data);
+        std::string write_to_string() const;
+
     // Mutable state
     private:
         std::vector<float> delay_line_;
@@ -18,8 +22,8 @@ class CLimiter {
 
     // Settings
     private:
-        const float attack_;
-        const float release_;
-        const int delay_;
-        const float threshold_;
-};
+        float attack_;
+        float release_;
+        int delay_;
+        float threshold_;
+};
\ No newline at end of file
